@@ -79,7 +79,7 @@ class RegistrationHandler(object):
     """
 
     def __init__(self, config, identity, reactor, exchange, pinger,
-                 message_store, cloud=False, fetch_async=None):
+                 message_store, fetch_async=None):
         self._config = config
         self._identity = identity
         self._reactor = reactor
@@ -94,7 +94,6 @@ class RegistrationHandler(object):
         self._exchange.register_message("registration",
                                         self._handle_registration)
         self._should_register = None
-        self._cloud = cloud
         self._fetch_async = fetch_async
         self._otp = None
         self._ec2_data = None
@@ -102,7 +101,7 @@ class RegistrationHandler(object):
     def should_register(self):
         id = self._identity
         # boolean logic is hard, I'm gonna use an if
-        if self._cloud:
+        if self._config.cloud:
             return bool(not id.secure_id
                         and self._message_store.accepts("register-cloud-vm"))
         return bool(not id.secure_id and id.computer_title and id.account_name
@@ -132,7 +131,7 @@ class RegistrationHandler(object):
     def _fetch_ec2_data(self):
         """Retrieve available EC2 information, if in a EC2 compatible cloud."""
         id = self._identity
-        if self._cloud and not id.secure_id:
+        if self._config.cloud and not id.secure_id:
             # Fetch data from the EC2 API, to be used later in the registration
             # process
             # We ignore errors from user-data because it's common for the
@@ -147,19 +146,23 @@ class RegistrationHandler(object):
                 "/meta-data/public-hostname",
                 "/meta-data/ami-launch-index",
                 "/meta-data/kernel-id",
-                "/meta-data/ramdisk-id",
                 "/meta-data/ami-id"]
             # We're not using a DeferredList here because we want to keep the
             # number of connections to the backend minimal. See lp:567515.
             for path in paths:
                 deferred.addCallback(
                     lambda ignore, path=path: self._get_data(path, ec2_data))
+            # Special case the ramdisk retrieval, because it may not be present
+            deferred.addCallback(
+                lambda ignore: self._fetch_async(
+                    EC2_API + "/meta-data/ramdisk-id").addErrback(log_failure))
+            deferred.addCallback(ec2_data.append)
 
             def record_data(ignore):
                 """Record the instance data returned by the EC2 API."""
                 (raw_user_data, instance_key, reservation_key,
                  local_hostname, public_hostname, launch_index,
-                 kernel_key, ramdisk_key, ami_key) = ec2_data
+                 kernel_key, ami_key, ramdisk_key) = ec2_data
                 self._ec2_data = {
                     "instance_key": instance_key,
                     "reservation_key": reservation_key,
@@ -170,6 +173,8 @@ class RegistrationHandler(object):
                     "ramdisk_key": ramdisk_key,
                     "image_key": ami_key}
                 for k, v in self._ec2_data.items():
+                    if v is None and k == "ramdisk_key":
+                        continue
                     self._ec2_data[k] = v.decode("utf-8")
                 self._ec2_data["launch_index"] = int(
                     self._ec2_data["launch_index"])
@@ -226,7 +231,7 @@ class RegistrationHandler(object):
                 tags = None
                 logging.error("Invalid tags provided for cloud "
                               "registration.")
-            if self._cloud and self._ec2_data is not None:
+            if self._config.cloud and self._ec2_data is not None:
                 if self._otp:
                     logging.info("Queueing message to register with OTP")
                     message = {"type": "register-cloud-vm",
@@ -364,7 +369,7 @@ def _wait_for_network():
     asynchronous; the network may not actually be up by the time the
     landscape-client init script is invoked.
     """
-    timeout = 5*60
+    timeout = 5 * 60
     port = 80
 
     start = time.time()
@@ -374,7 +379,7 @@ def _wait_for_network():
             s.connect((EC2_HOST, port))
             s.close()
             return
-        except socket.error, e:
+        except socket.error:
             time.sleep(1)
             if time.time() - start > timeout:
                 break
