@@ -3,7 +3,7 @@ import os
 from twisted.internet.defer import succeed, fail
 
 try:
-    from imagestore.eucaservice import FakeEucaInfo
+    from imagestore.eucaservice import FakeEucaInfo, EucaToolsError
 except ImportError:
     FakeEucaInfo = None
 
@@ -187,8 +187,10 @@ class EucalyptusTest(LandscapeTest):
         Eucalyptus, such as the C{imagestore} package not being available, an
         error message is sent to the server.
         """
+        plugin = self.get_plugin(fail(ZeroDivisionError("KABOOM!")))
 
         def check(ignore):
+            self.assertTrue(plugin.enabled)
             error_message = (
                 "Traceback (failure with no frames): "
                 "<type 'exceptions.ZeroDivisionError'>: KABOOM!\n")
@@ -198,7 +200,30 @@ class EucalyptusTest(LandscapeTest):
                 self.broker_service.message_store.get_pending_messages(),
                 [expected])
 
-        plugin = self.get_plugin(fail(ZeroDivisionError("KABOOM!")))
+        self.assertTrue(plugin.enabled)
+        deferred = plugin.run()
+        deferred.addCallback(check)
+        return deferred
+
+    def test_run_with_euca_tools_failure_message(self):
+        """
+        If a L{EucaToolsError} is raised when the plugin is run, it is
+        disabled.
+        """
+        plugin = self.get_plugin(fail(EucaToolsError("KABOOM!")))
+
+        def check(ignore):
+            self.assertFalse(plugin.enabled)
+            error_message = (
+                "Traceback (failure with no frames): "
+                "<class 'imagestore.eucaservice.EucaToolsError'>: KABOOM!\n")
+            expected = {"type": "eucalyptus-info-error",
+                        "error": error_message}
+            self.assertMessages(
+                self.broker_service.message_store.get_pending_messages(),
+                [expected])
+
+        self.assertTrue(plugin.enabled)
         deferred = plugin.run()
         deferred.addCallback(check)
         return deferred
@@ -221,6 +246,7 @@ class EucalyptusTest(LandscapeTest):
         skip_message = "imagestore module not available"
         test_failed_run_stops_service_hub.skip = skip_message
         test_run_with_failure_message.skip = skip_message
+        test_run_with_euca_tools_failure_message = skip_message
         test_run_with_successful_message.skip = skip_message
         test_successful_run_stops_service_hub.skip = skip_message
 
