@@ -1,32 +1,17 @@
+import os
+
 from twisted.internet.defer import maybeDeferred
 
 from landscape.lib.log import log_failure
+from landscape.lib.amp import RemoteObject
+from landscape.amp import (
+    ComponentProtocol, ComponentProtocolFactory, RemoteComponentConnector)
 
-from landscape.lib.dbus_util import method, get_object, Object
-from landscape.monitor.monitor import (MonitorPlugin, BUS_NAME, OBJECT_PATH,
-                                       IFACE_NAME)
+from landscape.monitor.plugin import MonitorPlugin
 from landscape.user.changes import UserChanges
 from landscape.user.provider import UserProvider
 
 
-class UserMonitorDBusObject(Object):
-    """
-    A DBUS object which exposes an API for getting the monitor to detect user
-    changes and upload them to the Landscape server.
-    """
-    object_path = OBJECT_PATH + "/UserMonitor"
-    iface_name = IFACE_NAME + ".UserMonitor"
-    bus_name = BUS_NAME
-
-    def __init__(self, bus, plugin):
-        super(UserMonitorDBusObject, self).__init__(bus)
-        self._plugin = plugin
-
-    @method(iface_name)
-    def detect_changes(self, operation_id=None):
-        return self._plugin.run(operation_id)
-
-
 class UserMonitor(MonitorPlugin):
     """
     A plugin which monitors the system user databases.
@@ -34,17 +19,33 @@ class UserMonitor(MonitorPlugin):
 
     persist_name = "users"
     run_interval = 3600 # 1 hour
+    name = "usermonitor"
 
     def __init__(self, provider=None):
         if provider is None:
             provider = UserProvider()
         self._provider = provider
+        self._port = None
 
     def register(self, registry):
         super(UserMonitor, self).register(registry)
+
         self.registry.reactor.call_on("resynchronize", self._resynchronize)
         self.call_on_accepted("users", self._run_detect_changes, None)
-        self._dbus_object = UserMonitorDBusObject(registry.bus, self)
+
+        factory = UserMonitorProtocolFactory(object=self)
+        socket = os.path.join(self.registry.config.sockets_path,
+                              self.name + ".sock")
+        self._port = self.registry.reactor.listen_unix(socket, factory)
+        from landscape.manager.usermanager import RemoteUserManagerConnector
+        self._user_manager_connector = RemoteUserManagerConnector(
+            self.registry.reactor, self.registry.config)
+
+    def stop(self):
+        """Stop listening for incoming AMP connections."""
+        if self._port:
+            self._port.stopListening()
+            self._port = None
 
     def _resynchronize(self):
         """Resynchronize user and group data."""
@@ -56,6 +57,8 @@ class UserMonitor(MonitorPlugin):
         return self.registry.broker.call_if_accepted(
             "users", self._run_detect_changes, operation_id)
 
+    detect_changes = run
+
     def _run_detect_changes(self, operation_id=None):
         """
         If changes are detected an C{urgent-exchange} is fired to send
@@ -64,22 +67,28 @@ class UserMonitor(MonitorPlugin):
         @param operation_id: When present it will be included in the
             C{operation-id} field.
         """
-        from landscape.manager.usermanager import UserManagerDBusObject
         # We'll skip checking the locked users if we're in monitor-only mode.
         if getattr(self.registry.config, "monitor_only", False):
             result = maybeDeferred(self._detect_changes,
                                    [], operation_id)
         else:
-            remote_service = get_object(self.registry.bus,
-                                        UserManagerDBusObject.bus_name,
-                                        UserManagerDBusObject.object_path)
 
-            result = remote_service.get_locked_usernames()
+            def get_locked_usernames(user_manager):
+                return user_manager.get_locked_usernames()
+
+            def disconnect(locked_usernames):
+                self._user_manager_connector.disconnect()
+                return locked_usernames
+
+            result = self._user_manager_connector.connect()
+            result.addCallback(get_locked_usernames)
+            result.addCallback(disconnect)
             result.addCallback(self._detect_changes, operation_id)
             result.addErrback(lambda f: self._detect_changes([], operation_id))
         return result
 
     def _detect_changes(self, locked_users, operation_id=None):
+
         def update_snapshot(result):
             changes.snapshot()
             return result
@@ -91,6 +100,7 @@ class UserMonitor(MonitorPlugin):
         self._provider.locked_users = locked_users
         changes = UserChanges(self._persist, self._provider)
         message = changes.create_diff()
+
         if message:
             message["type"] = "users"
             if operation_id:
@@ -99,3 +109,25 @@ class UserMonitor(MonitorPlugin):
             result.addCallback(update_snapshot)
             result.addErrback(log_error)
             return result
+
+
+class UserMonitorProtocol(ComponentProtocol):
+    """L{AMP}-based protocol for calling L{UserMonitor}'s methods remotely."""
+
+    methods = ["detect_changes"]
+
+
+class UserMonitorProtocolFactory(ComponentProtocolFactory):
+
+    protocol = UserMonitorProtocol
+
+
+class RemoteUserMonitor(RemoteObject):
+    """A connected remote L{UserMonitor}."""
+
+
+class RemoteUserMonitorConnector(RemoteComponentConnector):
+
+    factory = ComponentProtocolFactory
+    remote = RemoteUserMonitor
+    component = UserMonitor
