@@ -2,14 +2,15 @@ import os
 import re
 import logging
 
-from twisted.internet.defer import Deferred, succeed
+from twisted.internet.defer import succeed, Deferred
 
 from landscape.lib.lock import lock_path, LockError
 from landscape.lib.log import log_failure
 from landscape.lib.lsb_release import LSB_RELEASE_FILENAME, parse_lsb_release
+from landscape.reactor import TwistedReactor
 from landscape.deployment import Configuration, init_logging
 from landscape.package.store import PackageStore, InvalidHashIdDb
-from landscape.broker.remote import RemoteBroker
+from landscape.broker.amp import RemoteBrokerConnector
 
 
 class PackageTaskError(Exception):
@@ -43,24 +44,39 @@ class PackageTaskHandlerConfiguration(Configuration):
 class LazyRemoteBroker(object):
     """Wrapper class around L{RemoteBroker} providing lazy initialization.
 
-    This class is a wrapper around a regular L{RemoteBroker}. It creates
+    This class is a wrapper around a regular L{RemoteBroker}. It connects to
     the remote broker object only when one of its attributes is first accessed.
 
+    @param connector: The L{RemoteBrokerConnector} which will be used
+        to connect to the broker.
+
     @note: This behaviour is needed in particular by the ReleaseUpgrader and
-    the PackageChanger, because if the they connect early and DBus gets
-    upgraded while they run, they might crash or not be able to communicate
-    with the broker due to bugs in DBus.
+        the PackageChanger, because if the they connect early and the
+        landscape-client package gets upgraded while they run, they will lose
+        the connection and will not be able to reconnect for a potentially long
+        window of time (till the new landscape-client package version is fully
+        configured and the service is started again).
     """
 
-    def __init__(self, bus):
+    def __init__(self, connector):
+        self._connector = connector
         self._remote = None
-        self._bus = bus
 
-    def __getattr__(self, name):
-        if not self._remote:
-            from landscape.lib.dbus_util import get_bus
-            self._remote = RemoteBroker(get_bus(self._bus))
-        return getattr(self._remote, name)
+    def __getattr__(self, method):
+
+        if self._remote:
+            return getattr(self._remote, method)
+
+        def wrapper(*args, **kwargs):
+
+            def got_connection(remote):
+                self._remote = remote
+                return getattr(self._remote, method)(*args, **kwargs)
+
+            result = self._connector.connect()
+            return result.addCallback(got_connection)
+
+        return wrapper
 
 
 class PackageTaskHandler(object):
@@ -211,13 +227,10 @@ class PackageTaskHandler(object):
 
 
 def run_task_handler(cls, args, reactor=None):
-    from landscape.reactor import install
-    install()
-
     # please only pass reactor when you have totally mangled everything with
     # mocker. Otherwise bad things will happen.
     if reactor is None:
-        from twisted.internet import reactor
+        reactor = TwistedReactor()
 
     config = cls.config_factory()
     config.load(args)
@@ -237,7 +250,6 @@ def run_task_handler(cls, args, reactor=None):
         raise SystemExit("error: package %s is already running"
                          % program_name)
 
-
     words = re.findall("[A-Z][a-z]+", cls.__name__)
     init_logging(config, "-".join(word.lower() for word in words))
 
@@ -251,19 +263,26 @@ def run_task_handler(cls, args, reactor=None):
 
     package_store = PackageStore(config.store_filename)
     package_facade = SmartFacade()
-    remote = LazyRemoteBroker(config.bus)
 
-    handler = cls(package_store, package_facade, remote, config)
+    def finish():
+        connector.disconnect()
+        # For some obscure reason our TwistedReactor.stop method calls
+        # reactor.crash() instead of reactor.stop(), which doesn't work
+        # here. Maybe TwistedReactor.stop should simply use reactor.stop().
+        reactor.call_later(0, reactor._reactor.stop)
 
-    def got_err(failure):
+    def got_error(failure):
         log_failure(failure)
+        finish()
 
+    connector = RemoteBrokerConnector(reactor, config, retry_on_reconnect=True)
+    remote = LazyRemoteBroker(connector)
+    handler = cls(package_store, package_facade, remote, config)
     result = Deferred()
-    result.addCallback(lambda ignored: handler.run())
-    result.addErrback(got_err)
-    result.addBoth(lambda ignored: reactor.callLater(0, reactor.stop))
-    reactor.callWhenRunning(lambda: result.callback(None))
-
+    result.addCallback(lambda x: handler.run())
+    result.addCallback(lambda x: finish())
+    result.addErrback(got_error)
+    reactor.call_when_running(lambda: result.callback(None))
     reactor.run()
 
     return result
